from ._subunitwidth import SubunitwidthValidator
from ._subunitcolor import SubunitcolorValidator
from ._showsubunits import ShowsubunitsValidator
from ._showrivers import ShowriversValidator
from ._showocean import ShowoceanValidator
from ._showland import ShowlandValidator
from ._showlakes import ShowlakesValidator
from ._showframe import ShowframeValidator
from ._showcountries import ShowcountriesValidator
from ._showcoastlines import ShowcoastlinesValidator
from ._scope import ScopeValidator
from ._riverwidth import RiverwidthValidator
from ._rivercolor import RivercolorValidator
from ._resolution import ResolutionValidator
from ._projection import ProjectionValidator
from ._oceancolor import OceancolorValidator
from ._lonaxis import LonaxisValidator
from ._lataxis import LataxisValidator
from ._landcolor import LandcolorValidator
from ._lakecolor import LakecolorValidator
from ._framewidth import FramewidthValidator
from ._framecolor import FramecolorValidator
from ._domain import DomainValidator
from ._countrywidth import CountrywidthValidator
from ._countrycolor import CountrycolorValidator
from ._coastlinewidth import CoastlinewidthValidator
from ._coastlinecolor import CoastlinecolorValidator
from ._center import CenterValidator
from ._bgcolor import BgcolorValidator
